@@ -87,6 +87,8 @@ extern "C" {
 #include <codaconf.h>
 #include <vice_file.h>
 
+#define MAXNUMCLIENT 10
+
 static char *vicedir = NULL;
 
 extern int AL_DebugLevel;
@@ -116,6 +118,9 @@ static int AUTime = 0;			/* used to tell if binaries have changed */
 static int CheckOnly = 0;	/* only allow password checking at this server */
 static int DoRedirectLog = 1;	/* set to zero by -r switch on command line */
 
+struct UserInfo* client[MAXNUMCLIENT];
+int client_idx;
+
 void
 ReadConfigFile()
 {
@@ -175,6 +180,9 @@ int main(int argc, char **argv)
 #endif
     
     LogMsg(-1, 0, stdout, "Server successfully started");
+	
+    client_idx=0;
+    memset(client,0,sizeof(client));
 
     while(TRUE) {
 	cid = 0;
@@ -333,10 +341,25 @@ static void SetDebug()
 
 
 static void Terminate()
-    {
+{
+    int i;
+    struct UserInfo *ui;
+
+    for(i = 0; i < MAXNUMCLIENT; i++) {
+	if (!client[i]) continue;
+
+	ui = client[i];
+	client[i] = NULL;
+
+	RPC2_Unbind(ui->handle);
+	if (ui->UserCPS)
+	    AL_FreeCPS(&ui->UserCPS);
+	free(ui);
+    }
+
     LogMsg(-1, 0, stdout, "Terminate signal received .......quitting");
     exit(0);
-    }
+}
 
 
 static void CheckSignal()
@@ -481,28 +504,47 @@ void LogFailures(RPC2_Integer AuthenticationType, RPC2_CountedBS *cIdent,
 /* ============= Bodies of RPC routines follow =============  */
 
 long S_AuthNewConn(RPC2_Handle cid, RPC2_Integer seType, RPC2_Integer secLevel, RPC2_Integer encType, RPC2_Integer AuthType, RPC2_CountedBS *cIdent)
-    {
-    struct UserInfo *p;
+{
     int vid;
+    struct UserInfo *ui;
 
     vid = GetViceId(cIdent);
     LogMsg(0, AuthDebugLevel, stdout, "AuthNewConn(0x%x, %d, %d, %d, %d)",
-	cid, seType, secLevel, encType, vid);
-    p = (struct UserInfo *) malloc(sizeof(struct UserInfo));
-    RPC2_SetPrivatePointer(cid, (char *)p);
-    p->ViceId = vid;
-    p->HasQuit = FALSE;
-    p->UserCPS = NULL;
-    p->LastUsed = time(0);
-    return(0);
+	   cid, seType, secLevel, encType, vid);
+
+    if (client[client_idx]) {
+	ui = client[client_idx];
+	client[client_idx] = NULL;
+
+	RPC2_Unbind(ui->handle);
+	if (ui->UserCPS)
+	    AL_FreeCPS(&ui->UserCPS);
+	free(ui);
     }
 
+    ui = (struct UserInfo *) malloc(sizeof(*ui));
+    ui->handle = cid;
+    ui->ViceId = vid;
+    ui->HasQuit = FALSE;
+    ui->UserCPS = NULL;
+    ui->LastUsed = time(0);
+
+    RPC2_SetPrivatePointer(cid, (char *)ui);
+    client[client_idx++] = ui;
+
+    if (client_idx == MAXNUMCLIENT)
+	client_idx = 0;
+
+    return(0);
+}
+
 
 long S_AuthQuit(RPC2_Handle cid)
     {
-    struct UserInfo *p;
-    RPC2_GetPrivatePointer(cid, (char **)&p);
-    p->HasQuit = TRUE;
+    struct UserInfo *ui;
+    RPC2_GetPrivatePointer(cid, (void *)&ui);
+    if (ui)
+	ui->HasQuit = TRUE;
     return(0);
     }
 
@@ -513,8 +555,8 @@ long S_AuthGetTokens(RPC2_Handle cid, EncryptedSecretToken est, ClearToken *cTok
     struct UserInfo *ui;
     SecretToken sToken;
 
-    RPC2_GetPrivatePointer(cid, (char **)&ui);
-    if (ui == NULL || ui->HasQuit == TRUE) return(AUTH_FAILED);
+    RPC2_GetPrivatePointer(cid, (void *)&ui);
+    if (!ui || ui->HasQuit == TRUE) return(AUTH_FAILED);
     ui->LastUsed = time(0);
 
     /* First build clear token */
@@ -598,20 +640,20 @@ extern int IsAUser(int viceId);
 
 long S_AuthDeleteUser(RPC2_Handle cid, RPC2_Integer viceId)
 {
-	struct UserInfo *p;
+	struct UserInfo *ui;
 
 	/* Do not allow if this is a read only server	*/
 	if(CheckOnly)
 		return(AUTH_READONLY);
 	
 	/* make sure it's a system administrator */
-	RPC2_GetPrivatePointer(cid, (char **)&p);
-	if (p == NULL || p->HasQuit == TRUE) 
+	RPC2_GetPrivatePointer(cid, (void *)&ui);
+	if (!ui || ui->HasQuit == TRUE) 
 		return(AUTH_FAILED);
-	p->LastUsed = time(0);
-	if (!IsAdministrator(p)) {
+	ui->LastUsed = time(0);
+	if (!IsAdministrator(ui)) {
 		char buf1[PRS_MAXNAMELEN], buf2[PRS_MAXNAMELEN];
-		LogMsg(-1, 0, stdout, "AuthDeleteUser() attempt on  %s by %s denied", GetVname(viceId, buf1), GetVname(p->ViceId, buf2));
+		LogMsg(-1, 0, stdout, "AuthDeleteUser() attempt on  %s by %s denied", GetVname(viceId, buf1), GetVname(ui->ViceId, buf2));
 		return(AUTH_DENIED);
 	}
 	if (!IsAUser(viceId)) 
