@@ -361,7 +361,7 @@ static int dir_DirEntry2VDirent(PDirEntry ep, struct venus_dirent *vd, VolumeId
 	vd->d_type = 0;
 #endif
 	vd->d_namlen = strlen(ep->name);
-	if (vd->d_namlen > CODA_MAXNAMLEN)
+	if (vd->d_namlen >= CODA_MAXNAMLEN)
 		vd->d_namlen = CODA_MAXNAMLEN;
 	strncpy(vd->d_name, ep->name, vd->d_namlen);
 	vd->d_name[vd->d_namlen] = '\0';
@@ -1016,7 +1016,7 @@ struct DirEntry *dir_GetBlob (struct DirHeader *dir, long blobno)
 /* Hash a string to a number between 0 and NHASH. */
 int DIR_Hash (const char *string)
 {
-    char tc;
+    signed char tc;
     int hval, tval;
 
     hval = 0;
