@@ -90,8 +90,10 @@ int main(int argc, char **argv)
     }
     else if ( argc != 3 ) {
 	printf(INITHELPMSG);
+#if 0
 	if (GetTokens()) /* warn user if no tokens are found */
 	    fprintf(stderr, "\n\n\nWARNING: YOU DON'T HAVE TOKENS.  YOU MIGHT WANT TO AUTHENTICATE FIRST\n\n\a");
+#endif
 	GetArgs(argc, argv);
 	Parser_init("repair > ", list);
 	Parser_commands();
@@ -282,7 +284,7 @@ void rep_CheckLocal(int largc, char **largv) {
     vioc.out = space;
     vioc.out_size = DEF_BUF;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_CHECK)");
     printf("%s\n", vioc.out);
     fflush(stdout);
@@ -364,7 +366,7 @@ void rep_DiscardLocal(int largc, char **largv) {
     vioc.in = buf;    
     vioc.in_size = (short) strlen(buf) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_DISCARD)");
     printf("%s\n", vioc.out);
     fflush(stdout);
@@ -440,24 +442,25 @@ void rep_ListLocal(int largc, char **largv)
     vioc.out = space;
     vioc.out_size = DEF_BUF;
     strcpy(filename, "/tmp/listlocal.XXXXXX");
-    mktemp(filename);
+    fd = mkstemp(filename);
+    if (fd < 0) {
+	perror(filename);
+	return;
+    }
+
     vioc.in = buf;
     sprintf(buf, "%d %s", REP_CMD_LIST, filename);
     vioc.in_size = (short) strlen(vioc.in) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_LIST)");
     printf("%s\n", vioc.out);
     fflush(stdout);
     if (rc == 0) {
-	fd = open(filename, O_RDONLY, 0);
-	if (fd < 0) perror(filename);
-	else {
-	    while ((n = read(fd, buf, DEF_BUF)) > 0)
-		write(1, buf, n);
-	    close(fd);
-	}
+	while ((n = read(fd, buf, DEF_BUF)) > 0)
+	    write(1, buf, n);
     }
+    close(fd);
     unlink(filename);
 }
 
@@ -476,7 +479,7 @@ void rep_PreserveAllLocal(int largc, char **largv) {
     vioc.in = buf;
     vioc.in_size = (short) strlen(buf) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_PRESERVE_ALL)");
     printf("%s\n", vioc.out);
     fflush(stdout);
@@ -496,7 +499,7 @@ void rep_PreserveLocal(int largc, char **largv) {
     vioc.in = buf;
     vioc.in_size = (short) strlen(buf) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMU_PRESERVE)");
     printf("%s\n", vioc.out);
     fflush(stdout);
@@ -600,7 +603,7 @@ void rep_SetGlobalView(int largc, char **largv)
     vioc.in = buf;
     vioc.in_size = (short) strlen(buf) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_GLOBAL_VIEW)");
     printf("%s\n", vioc.out);
     fflush(stdout);
@@ -620,7 +623,7 @@ void rep_SetLocalView(int largc, char **largv) {
     vioc.in = buf;
     vioc.in_size = (short) strlen(buf) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_LOCAL_VIEW)");
     printf("%s\n", vioc.out);
     fflush(stdout);
@@ -640,7 +643,7 @@ void rep_SetMixedView(int largc, char **largv) {
     vioc.in = buf;
     vioc.in_size = (short) strlen(buf) + 1;
 
-    rc = pioctl("/coda", VIOC_REP_CMD, &vioc, 0);
+    rc = pioctl("/coda", _VICEIOCTL(_VIOC_REP_CMD), &vioc, 0);
     if (rc < 0) perror("VIOC_REP_CMD(REP_CMD_MIXED_VIEW)");
     printf("%s\n", vioc.out);
     fflush(stdout);
