@@ -461,14 +461,16 @@ void srvent::Reset() {
 
     /* Kill all conninfos with this server */
     conninfo_iterator conninfo_next;
-    conninfo *cip;
-    while((cip = conninfo_next()))
+    conninfo *cip, *n = NULL;
+    while((cip = n ? n : conninfo_next())) {
+	n = NULL;
 	if (cip->GetRemoteHost() == host){
 	    conninfo::CInfoTab->remove(&cip->tblhandle);
 	    conninfo::ncinfos--;
+	    n = conninfo_next();
 	    delete cip;
 	}
-    
+    }
 }
 
 void srvent::ServerError(int *codep) {
@@ -678,7 +680,7 @@ conninfo *GetConnectionInfo(RPC2_Handle cid) {
 }
 
 
-void ResCheckServerLWP() 
+void ResCheckServerLWP(void *arg) 
 {
     struct timeval delay;
     LogMsg(1, SrvDebugLevel, stdout,  "Starting RecCheckServerLWP");
@@ -692,7 +694,7 @@ void ResCheckServerLWP()
 }
 
 /* LWP to check if servers are alive */
-void ResCheckServerLWP_worker() 
+void ResCheckServerLWP_worker(void *arg) 
 {
     struct timeval delay;
     LogMsg(1, SrvDebugLevel, stdout,  "Starting RecCheckServerLWP_worker");
