@@ -122,14 +122,13 @@ static void SwapLog();
 static void U_InitRPC();
 static int U_BindToServer(char *fileserver, RPC2_Handle *RPCid);
 
-static int Rebind = 0;
 static int ReadOnlyAllowed = 0;
 static int CheckAll = 1;
 
 static RPC2_Integer operatorSecs = 0;
 static RPC2_Integer operatorUsecs = 0;
 
-static RPC2_Handle con;
+static RPC2_Handle con = 0;
 static char host[256];
 static int waitinterval = 30;	/* 5 min */
 static int reps = 6;
@@ -221,7 +220,6 @@ int main(int argc, char **argv)
     RPC2_DebugLevel = SrvDebugLevel / 10;
 
     U_InitRPC();
-    Rebind = 1;
 
     gettimeofday(&tp, &tsp);
     LogMsg(0, SrvDebugLevel, stdout, 
@@ -234,11 +232,12 @@ int main(int argc, char **argv)
 
     while (1) {
 
-	if (Rebind) {
+	if (!con) {
 	    ReConnect();
-	    Rebind = 0;
 	    i = reps;
 	}
+	if (!con)
+	    goto retry;
 
 	/* Checking "db" relative to updatesrv working directory. */
 	if (CheckDir("db", 0644)) {
@@ -293,6 +292,7 @@ int main(int argc, char **argv)
 
 	CheckAll = 1;
 
+retry:
 	IOMGR_Select(0, 0, 0, 0, &time);
     }
 }
@@ -335,8 +335,8 @@ ReadConfigFile()
     /* Load configuration file to get vice dir. */
     codaconf_init("server.conf");
 
-    CONF_STR(vicedir, "vicedir", "/vice");
-    CONF_INT(nservers, "numservers", 1); 
+    CODACONF_STR(vicedir, "vicedir", "/vice");
+    CODACONF_INT(nservers, "numservers", 1); 
 
     vice_dir_init(vicedir, 0);
 
@@ -351,9 +351,9 @@ ReadConfigFile()
         for (int i = 0; i<nservers; i++) {
 	    hostlist[i] = new char[256];
 	    hostlist[i][0] = '\0';
-	    sprintf (confname, "server_%d", i+1);
+	    sprintf (confname, "server_%d.conf", i+1);
 	    codaconf_init(confname);
-	    CONF_STR(hostlist[i],  "hostname",  "");
+	    CODACONF_STR(hostlist[i],  "hostname",  "");
 	    if (hostlist[i][0] == '\0') {
 	        LogMsg(0, SrvDebugLevel, stdout,
 		       "No host name for server %d.\n",
@@ -533,7 +533,8 @@ static int CheckFile(char *fileName, int mode)
 	LogMsg(0, SrvDebugLevel, stdout, "Fetch failed for '%s' with %s\n",
 	       fileName, ViceErrorMsg((int)rc));
 	if (rc <= RPC2_ELIMIT) {
-	    Rebind = 1;
+	    RPC2_Unbind(con);
+	    con = 0;
 	}
 	return(0);
     }
@@ -584,76 +585,64 @@ static int CheckFile(char *fileName, int mode)
 static void ReConnect()
 {
     long     rc;
-    struct timeval  time;
-    RPC2_PortIdent sid;
     RPC2_SubsysIdent ssid;
-    RPC2_HostIdent hid;
+    RPC2_HostIdent hident;
+    RPC2_PortIdent pident;
     RPC2_CountedBS cident;
     RPC2_EncryptionKey secret;
     char hostname[64];
-    int     i;
     long portmapid;
     long port;
 
-    if (con != 0) {
+    if (con) {
 	LogMsg(0, SrvDebugLevel, stdout, "Unbinding\n");
 	RPC2_Unbind(con);
+	con = 0;
     }
 
-    for (i = 0; i < 100; i++) {
-	    portmapid = portmap_bind(host);
-	    if ( !portmapid ) {
-		    fprintf(stderr, "Cannot bind to rpc2portmap; exiting\n");
-		    IOMGR_Select(0, 0, 0, 0, &time);
-		    continue;
-	    }
-	    rc = portmapper_client_lookup_pbynvp(portmapid, (unsigned char *)"codaupdate", 0, 17, &port);
-	    
-	    if ( rc ) {
-		    fprintf(stderr, "Cannot get port from rpc2portmap; exiting\n");
-		    RPC2_Unbind(portmapid);
-		    IOMGR_Select(0, 0, 0, 0, &time);
-		    continue;
-	    } else 
-		    RPC2_Unbind(portmapid);
-
-	    
-	    hid.Tag = RPC2_HOSTBYNAME;
-	    strcpy(hid.Value.Name, host);
-	    sid.Tag = RPC2_PORTBYINETNUMBER;
-	    sid.Value.InetPortNumber = htons(port);
-	    ssid.Tag = RPC2_SUBSYSBYID;
-	    ssid.Value.SubsysId= SUBSYS_UPDATE;
-	    
-	    time.tv_sec = waitinterval;
-	    time.tv_usec = 0;
-	    
-	    RPC2_BindParms bparms;
-	    memset((void *)&bparms, 0, sizeof(bparms));
-	    bparms.SecurityLevel = RPC2_AUTHONLY;
-	    bparms.EncryptionType = RPC2_XOR;
-	    bparms.SideEffectType = SMARTFTP;
-
-	    gethostname(hostname, 63); hostname[63] = '\0';
-	    cident.SeqBody = (RPC2_ByteSeq)&hostname;
-	    cident.SeqLen = strlen(hostname) + 1;
-	    bparms.ClientIdent = &cident;
-
-	    GetSecret(vice_sharedfile("db/update.tk"), secret);
-	    bparms.SharedSecret = &secret;
-
-	    if ((rc = RPC2_NewBinding(&hid, &sid, &ssid, &bparms, &con))) {
-		    LogMsg(0, SrvDebugLevel, stdout, 
-			   "Bind failed with %s\n", 
-			   (char *)ViceErrorMsg((int)rc));
-		    if (rc < RPC2_ELIMIT)
-			    IOMGR_Select(0, 0, 0, 0, &time);
-		    else
-			    break;
-	    }
-	    else
-		    return ;
+    portmapid = portmap_bind(host);
+    if ( !portmapid ) {
+	fprintf(stderr, "Cannot bind to rpc2portmap; exiting\n");
+	return;
     }
+
+    rc = portmapper_client_lookup_pbynvp(portmapid,
+					 (unsigned char *)"codaupdate", 0, 17,
+					 &port);
+    RPC2_Unbind(portmapid);
+    if (rc) {
+	fprintf(stderr, "Cannot get port from rpc2portmap; exiting\n");
+	return;
+    }
+
+    hident.Tag = RPC2_HOSTBYNAME;
+    strcpy(hident.Value.Name, host);
+    pident.Tag = RPC2_PORTBYINETNUMBER;
+    pident.Value.InetPortNumber = htons(port);
+    ssid.Tag = RPC2_SUBSYSBYID;
+    ssid.Value.SubsysId= SUBSYS_UPDATE;
+
+    RPC2_BindParms bparms;
+    memset((void *)&bparms, 0, sizeof(bparms));
+    bparms.SecurityLevel = RPC2_AUTHONLY;
+    bparms.EncryptionType = RPC2_XOR;
+    bparms.SideEffectType = SMARTFTP;
+
+    gethostname(hostname, 63); hostname[63] = '\0';
+    cident.SeqBody = (RPC2_ByteSeq)&hostname;
+    cident.SeqLen = strlen(hostname) + 1;
+    bparms.ClientIdent = &cident;
+
+    GetSecret(vice_sharedfile("db/update.tk"), secret);
+    bparms.SharedSecret = &secret;
+
+    rc = RPC2_NewBinding(&hident, &pident, &ssid, &bparms, &con);
+    if (rc) {
+	LogMsg(0, SrvDebugLevel, stdout, "Bind failed with %s\n", 
+	       (char *)ViceErrorMsg((int)rc));
+	return;
+    }
+    /* success, we have a new connection */
 }
 
 
@@ -714,6 +703,7 @@ static void U_InitRPC()
     FILE *tokfile;
     SFTP_Initializer sftpi;
     long rcode;
+    RPC2_Options options;
 
     /* store authentication key */
     tokfile = fopen(vice_sharedfile(VolTKFile), "r");
@@ -729,7 +719,11 @@ static void U_InitRPC()
     sftpi.SendAhead = 4;
     sftpi.AckPoint = 4;
     SFTP_Activate(&sftpi);
-    rcode = RPC2_Init(RPC2_VERSION, 0, NULL, -1, 0);
+
+    memset(&options, 0, sizeof(options));
+    options.Flags = RPC2_OPTION_IPV6;
+
+    rcode = RPC2_Init(RPC2_VERSION, &options, NULL, -1, 0);
     if (rcode != RPC2_SUCCESS) {
 	LogMsg(0, SrvDebugLevel, stdout, "RPC2_Init failed with %s\n", RPC2_ErrorMsg((int)rcode));
 	exit(-1);
@@ -745,7 +739,7 @@ static int U_BindToServer(char *fileserver, RPC2_Handle *RPCid)
     RPC2_PortIdent pident;
     RPC2_SubsysIdent sident;
     RPC2_EncryptionKey secret;
-    long     rcode;
+    long rcode;
 
     hident.Tag = RPC2_HOSTBYNAME;
     strcpy(hident.Value.Name, fileserver);
