@@ -105,7 +105,7 @@ static void ReadConfigFile();
 static void SetDebug();
 static void ResetDebug();
 static void Terminate();
-static void ServerLWP(int *Ident);
+static void ServerLWP(void *);
 
 static char *prefix = NULL;
 
@@ -186,6 +186,7 @@ int main(int argc, char **argv)
     long portmapid;
     struct stat statbuf;
     char *miscdir;
+    int port = 0;
 
     /* process the command line arguments */
     for (i = 1; i < argc; i++) {
@@ -194,6 +195,8 @@ int main(int argc, char **argv)
 	    SrvDebugLevel = atoi(argv[++i]);  
 	else if (!strcmp(argv[i], "-l"))
 	    lwps = atoi(argv[++i]);
+	else if (!strcmp(argv[i], "-port"))
+	    port = atoi(argv[++i]);
 	else if (!strcmp(argv[i], "-p")) {
 	    prefix = argv[++i];
 	} else if (!strcmp(argv[i], "-q")) {
@@ -262,7 +265,7 @@ int main(int argc, char **argv)
     CODA_ASSERT(LWP_Init(LWP_VERSION, LWP_MAX_PRIORITY - 1, &parentPid) == LWP_SUCCESS);
 
     port1.Tag = RPC2_PORTBYINETNUMBER;
-    port1.Value.InetPortNumber = 0;
+    port1.Value.InetPortNumber = htons(port);
 
     SFTP_SetDefaults(&sftpi);
     sftpi.PacketSize = 1024;
@@ -302,9 +305,9 @@ int main(int argc, char **argv)
 
     for (i = 0; i < lwps; i++) {
 	sprintf(sname, "ServerLWP-%d", i);
-	CODA_ASSERT(LWP_CreateProcess((PFIC)ServerLWP, 
-				 32 * 1024, LWP_MAX_PRIORITY - 1,
-				 (char *)&i, sname, &serverPid) 
+	CODA_ASSERT(LWP_CreateProcess(ServerLWP, 32 * 1024,
+				      LWP_MAX_PRIORITY - 1,
+				      &i, sname, &serverPid) 
 	       == LWP_SUCCESS);
     }
     gettimeofday(&tp, &tsp);
@@ -380,8 +383,9 @@ static long Update_AuthFail(RPC2_Integer authtype,
     return 0;
 }
 
-static void ServerLWP(int *Ident)
+static void ServerLWP(void *arg)
 {
+    int *Ident = (int *)arg;
     RPC2_RequestFilter myfilter;
     RPC2_PacketBuffer * myrequest;
     RPC2_Handle mycid;
