@@ -57,6 +57,7 @@ extern int global_kernfd;
 #endif
 
 /* interfaces */
+#include <user.h>
 #include <vice.h>
 #include <adv_skk.h>
 
@@ -500,13 +501,13 @@ class fsobj {
     void GC();
     int Flush();
     void UpdateStatus(ViceStatus *, ViceVersionVector *, uid_t);
-    int StatusEq(ViceStatus *, int);
+    int StatusEq(ViceStatus *);
     void ReplaceStatus(ViceStatus *, ViceVersionVector *);
     int CheckRcRights(int);
     void SetRcRights(int);
     void ClearRcRights();
     int IsValid(int);
-    void SetAcRights(uid_t, long my_rights, long any_rights);
+    void SetAcRights(uid_t uid, long my_rights, long any_rights);
     void DemoteAcRights(uid_t);
     void PromoteAcRights(uid_t);
     void ClearAcRights(uid_t);
@@ -659,13 +660,18 @@ class fsobj {
     void Release(int writep);
     int Close(int writep, uid_t uid);
     int Access(long, int, uid_t);
-    int Lookup(fsobj **, VenusFid *, char *, uid_t, int);
+    int Lookup(fsobj **, VenusFid *, char *, uid_t, int flags);
+// These are defined in lib-src/kernel-includes/coda.h
+// #define CLU_CASE_SENSITIVE	0x01
+// #define CLU_CASE_INSENSITIVE 0x02
+#define CLU_CASE_MASK		0x03
+#define CLU_TRAVERSE_MTPT	0x04
     int Readdir(char *, int, int, int *, uid_t);
     int Readlink(char *, unsigned long, int *, uid_t);
 
     /* Miscellaneous utility routines. */
     int dir_Lookup(char *, VenusFid *, int);
-    int CheckAcRights(uid_t, long rights, int connected);
+    int CheckAcRights(uid_t uid, long rights, int connected);
     void GetVattr(struct coda_vattr *);		/* translate attributes to VFS format */
     void GetFid(VenusFid *f) { *f = fid; }
     void ReturnEarly();
