@@ -146,10 +146,14 @@ fsobj::fsobj(VenusFid *key, char *name) : cf() {
 /* local-repair modification */
 /* MUST be called from within transaction! */
 /* Caller sets range for whole object! */
-void fsobj::ResetPersistent() {
+void fsobj::ResetPersistent()
+{
     MagicNumber = FSO_MagicNumber;
     fid = NullFid;
-    comp = NULL;
+    if (comp) {
+	rvmlib_rec_free(comp);
+	comp = NULL;
+    }
     vol = 0;
     state = FsoRunt;
     stat.VnodeType = Invalid;
@@ -669,6 +673,8 @@ int fsobj::Flush() {
 /* Called as result of {GetAttr, ValidateAttr, GetData, ValidateData}. */
 void fsobj::UpdateStatus(ViceStatus *vstat, vv_t *UpdateSet, uid_t uid)
 {
+    int isrunt = !HAVESTATUS(this);
+
     /* Mount points are never updated. */
     if (IsMtPt())
 	{ print(logFile); CHOKE("fsobj::UpdateStatus: IsMtPt!"); }
@@ -678,16 +684,21 @@ void fsobj::UpdateStatus(ViceStatus *vstat, vv_t *UpdateSet, uid_t uid)
 
     LOG(100, ("fsobj::UpdateStatus: (%s), uid = %d\n", FID_(&fid), uid));
 
-    if (HAVESTATUS(this)) {		/* {ValidateAttr} */
-      if (!StatusEq(vstat, 0))
-	    ReplaceStatus(vstat, UpdateSet);
-    }
-    else {				/* {GetAttr} */
+    /*
+     * We have to update the status when we have,
+     *  - runt objects (first GetAttr for the fso)
+     *  - UpdateSet is non-NULL (Store/SetAttr/Create/..., mutating operations)
+     *  - vstat differs (ValidateAttrs)
+     */
+    if (isrunt || UpdateSet || !StatusEq(vstat))
 	ReplaceStatus(vstat, UpdateSet);
-	Matriculate();
-    }
 
-    /* Set access rights and parent (if they differ). */
+    /* If this object is a runt, there may be others waiting for the create
+     * to finalize */
+    if (isrunt)
+	Matriculate();
+
+    /* Update access rights and parent (if they differ). */
     if (IsDir())
 	SetAcRights(uid, vstat->MyAccess, vstat->AnyAccess);
 
@@ -696,10 +707,10 @@ void fsobj::UpdateStatus(ViceStatus *vstat, vv_t *UpdateSet, uid_t uid)
 
 
 /* Need not be called from within transaction. */
-int fsobj::StatusEq(ViceStatus *vstat, int Mutating)
+int fsobj::StatusEq(ViceStatus *vstat)
 {
     int eq = 1;
-    int log = (Mutating || HAVEDATA(this));
+    int log = HAVEDATA(this);
 
     if (stat.Length != vstat->Length) {
 	eq = 0;
@@ -719,7 +730,7 @@ int fsobj::StatusEq(ViceStatus *vstat, int Mutating)
 			FID_(&fid), stat.DataVersion, vstat->DataVersion));
 	}
     } else {
-	if (!Mutating && VV_Cmp(&stat.VV, &vstat->VV) != VV_EQ) {
+	if (VV_Cmp(&stat.VV, &vstat->VV) != VV_EQ) {
 	    eq = 0;
 	    if (log)
 		LOG(0, ("fsobj::StatusEq: (%s), VVs differ\n", FID_(&fid)));
@@ -755,7 +766,6 @@ int fsobj::StatusEq(ViceStatus *vstat, int Mutating)
 	    LOG(0, ("fsobj::StatusEq: (%s), VnodeType %d != %d\n",
 		    FID_(&fid), stat.VnodeType, (int)vstat->VnodeType));
     }
-
     return(eq);
 }
 
@@ -784,13 +794,13 @@ void fsobj::ReplaceStatus(ViceStatus *vstat, vv_t *UpdateSet)
     /* nice optimization, but repair is looking at version vectors in not
      * necessarily replicated volumes (although the IsReadWriteRep test should
      * have matched in that case) */
-    //if (vol->IsReplicated() || vol->IsReadWriteReplica())
-    if (UpdateSet == 0)
-	stat.VV = vstat->VV;
-    else {
+    //if (!vol->IsReplicated() && !vol->IsReadWriteReplica())
+    if (UpdateSet) {
 	stat.VV.StoreId = vstat->VV.StoreId;
 	AddVVs(&stat.VV, UpdateSet);
-    }
+    } else
+	stat.VV = vstat->VV;
+
     stat.Date = vstat->Date;
     stat.Owner = (uid_t) vstat->Owner;
     stat.Mode = (short) vstat->Mode;
@@ -869,29 +879,44 @@ int fsobj::IsValid(int rcrights) {
 /* Returns {0, EACCES, ENOENT}. */
 int fsobj::CheckAcRights(uid_t uid, long rights, int connected)
 {
-    if (uid != ANYUSER_UID) {
+    userent *ue = vol->realm->GetUser(uid);
+    long allowed;
+
+    if (ue != vol->realm->system_anyuser) {
+	CODA_ASSERT(uid == ue->GetUid());
 	/* Do we have this user's rights in the cache? */
 	for (int i = 0; i < CPSIZE; i++) {
 	    if (SpecificUser[i].inuse && (!connected || SpecificUser[i].valid)
-		&& uid == SpecificUser[i].uid)
-		return((rights & SpecificUser[i].rights) ? 0 : EACCES);
+		&& uid == SpecificUser[i].uid) {
+		allowed = SpecificUser[i].rights;
+		goto exit_found;
+	    }
 	}
     }
-    if (uid == ANYUSER_UID || !connected) {
+    if (ue == vol->realm->system_anyuser || !connected) {
 	/* Do we have access via System:AnyUser? */
-	if (AnyUser.inuse && (!connected || AnyUser.valid))
-	    return((rights & AnyUser.rights) ? 0 : EACCES);
+	if (AnyUser.inuse && (!connected || AnyUser.valid)) {
+	    allowed = AnyUser.rights;
+	    goto exit_found;
+	}
     }
+    PutUser(&ue);
 
     LOG(10, ("fsobj::CheckAcRights: not found, (%s), (%d, %d, %d)\n",
 	      FID_(&fid), uid, rights, connected));
     return(ENOENT);
+
+exit_found:
+    PutUser(&ue);
+    return (rights & allowed) ? 0 : EACCES;
 }
 
 
 /* MUST be called from within transaction! */
 void fsobj::SetAcRights(uid_t uid, long my_rights, long any_rights)
 {
+    userent *ue = vol->realm->GetUser(uid);
+
     LOG(100, ("fsobj::SetAcRights: (%s), uid = %d, my_rights = %d, any_rights = %d\n",
 	       FID_(&fid), uid, my_rights, any_rights));
 
@@ -902,11 +927,14 @@ void fsobj::SetAcRights(uid_t uid, long my_rights, long any_rights)
     }
     AnyUser.valid = 1;
 
-    /* Don't record my_rights if we're not really authenticated! */
-    userent *ue = vol->realm->GetUser(uid);
-    int tokensvalid = ue->TokensValid();
+    /* Don't record my_rights if we're system_anyuser! */
+    if (ue == vol->realm->system_anyuser) {
+	PutUser(&ue);
+	return;
+    }
+
+    CODA_ASSERT(uid == ue->GetUid());
     PutUser(&ue);
-    if (!tokensvalid) return;
 
     int i;
     int j = -1;
@@ -1201,12 +1229,9 @@ int fsobj::TryToCover(VenusFid *inc_fid, uid_t uid)
 
     /* Do the mount magic. */
     Recov_BeginTrans();
-    if (IsFake() && !rf->IsRoot()) {
-	    RVMLIB_REC_OBJECT(rf->mvstat);
-	    RVMLIB_REC_OBJECT(rf->u.mtpoint);
-	    rf->mvstat = ROOT;
-	    rf->u.mtpoint = 0;
-    }
+    RVMLIB_REC_OBJECT(rf->mvstat);
+    CODA_ASSERT(rf->u.mtpoint == 0);
+    rf->mvstat = ROOT;
     rf->MountRoot(this);
     CoverMtPt(rf);
     Recov_EndTrans(MAXFP);
@@ -1329,7 +1354,7 @@ void fsobj::AttachChild(fsobj *child) {
 
     if (child->child_link.is_linked())
 	{ print(logFile); child->print(logFile); CHOKE("fsobj::AttachChild: bad child"); }
-    if (children == 0)
+    if (!children)
 	children = new dlist;
     children->prepend(&child->child_link);
 
@@ -1348,7 +1373,7 @@ void fsobj::DetachChild(fsobj *child) {
     DemoteHdbBindings();	    /* in case an expansion would no longer be satisfied! */
 
     if (child->pfso != this || !child->child_link.is_linked() ||
-	 children == 0 || children->count() == 0)
+	!children || children->count() == 0)
 	{ print(logFile); child->print(logFile); CHOKE("fsobj::DetachChild: bad child"); }
     if (children->remove(&child->child_link) != &child->child_link)
 	{ print(logFile); child->print(logFile); CHOKE("fsobj::DetachChild: remove failed"); }
@@ -2294,28 +2319,33 @@ void fsobj::UnLock(LockLevel level) {
 
 /*  *****  Miscellaneous Utility Routines  *****  */
 
-void fsobj::GetVattr(struct coda_vattr *vap) {
+void fsobj::GetVattr(struct coda_vattr *vap)
+{
     /* Most attributes are derived from the VenusStat structure. */
     vap->va_type = FTTOVT(stat.VnodeType);
     vap->va_mode = stat.Mode;
 
-    if (S_ISREG(stat.Mode)) /* strip the setuid bits on files! */
+    if (stat.VnodeType == File) /* strip the setuid bits on files! */
         vap->va_mode &= ~(S_ISUID | S_ISGID);
 
     vap->va_uid = (uid_t) stat.Owner;
     vap->va_gid = V_GID;
 
-    vap->va_fileid = (IsRoot() && u.mtpoint && !IsVenusRoot())
+    vap->va_fileid = (IsRoot() && u.mtpoint)
 		       ? FidToNodeid(&u.mtpoint->fid)
 		       : FidToNodeid(&fid);
 
-    vap->va_nlink = stat.LinkCount;
+    /* hack to avoid an optimization where find skips subdirectories if
+     * there are any mountpoints in the current directory (since the
+     * mountlinks don't are not represented in the link count). */
+    vap->va_nlink = (stat.VnodeType == Directory) ? 1 : stat.LinkCount;
     vap->va_blocksize = V_BLKSIZE;
     vap->va_rdev = 1;
 
     /* If the object is currently open for writing we must physically 
        stat it to get its size and time info. */
-    if (WRITING(this)) {
+    if (WRITING(this))
+    {
 	struct stat tstat;
 	cf.Stat(&tstat);
 
@@ -2334,8 +2364,7 @@ void fsobj::GetVattr(struct coda_vattr *vap) {
     vap->va_bytes = NBLOCKS_BYTES(vap->va_size);
 
     /* We don't keep track of atime/ctime, so keep them identical to mtime */
-    vap->va_atime = vap->va_mtime;
-    vap->va_ctime = vap->va_mtime;
+    vap->va_atime = vap->va_ctime = vap->va_mtime;
 
     VPROC_printvattr(vap);
 }
@@ -2381,6 +2410,7 @@ void fsobj::ReturnEarly() {
 	    {
 	    /* Huh. IOCTL in the kernel thinks there may be return data. Assume not. */
 	    out = (union outputArgs *)w->msg->msg_buf;
+	    out->coda_ioctl.data = (char *)sizeof(struct coda_ioctl_out); 
 	    out->coda_ioctl.len = 0; 
 	    out->coda_ioctl.oh.result = 0;
 	    w->Return(w->msg, sizeof (struct coda_ioctl_out));
@@ -2596,9 +2626,9 @@ void fsobj::print(int fdes) {
     fdprint(fdes, "\tvoltype = [%d %d %d], fake = %d, fetching = %d local = %d\n",
 	     vol->IsBackup(), vol->IsReplicated(), vol->IsReadWriteReplica(),
 	     flags.fake, flags.fetching, flags.local);
-    fdprint(fdes, "\trep = %d, data = %d, owrite = %d, dirty = %d, shadow = %d\n",
+    fdprint(fdes, "\trep = %d, data = %d, owrite = %d, dirty = %d, shadow = %d ckmtpt\n",
 	     REPLACEABLE(this), HAVEDATA(this), flags.owrite, flags.dirty,
-	     shadow != 0);
+	     shadow != 0, flags.ckmtpt);
 
     /* < mvstat [rootfid | mtptfid] > */
     fdprint(fdes, "\tmvstat = %s", PrintMvStat(mvstat));
@@ -2667,31 +2697,17 @@ void fsobj::ListCache(FILE *fp, int long_format, unsigned int valid)
      list fsobjs
           such as valid (valid == 1), non-valid (valid == 2) or all (valid == 3) */
 
+  int isvalid = DATAVALID(this) && STATUSVALID(this);
   char path[MAXPATHLEN];
   GetPath(path, 0);		/* Get relative pathname. */    
 
-  switch (valid) {
-  case 1: /* only valid */
-    if ( DATAVALID(this) && STATUSVALID(this) )
-      if (!long_format)
-	ListCacheShort(fp);
-      else
-	ListCacheLong(fp);
-    break;
-  case 2: /* only non-valid */
-    if ( !DATAVALID(this) || !STATUSVALID(this) )
-      if (!long_format)
-	ListCacheShort(fp);
-      else
-	ListCacheLong(fp);
-    break;
-  case 3: /* all */
-  default:
-      if (!long_format)
-	ListCacheShort(fp);
-      else
-	ListCacheLong(fp);
-  }
+  if (valid == 1 && !isvalid) return;
+  if (valid == 2 && isvalid) return;
+
+  if (!long_format)
+      ListCacheShort(fp);
+  else
+      ListCacheLong(fp);
 }
 
 void fsobj::ListCacheShort(FILE* fp)
