@@ -178,7 +178,7 @@ unsigned int repvol::deallocs = 0;
 #endif
 
 /* local-repair modification */
-void VolInit()
+void VolInit(void)
 {
     /* Allocate the database if requested. */
     if (InitMetaData) {					/* <==> VDB == 0 */
@@ -198,11 +198,14 @@ void VolInit()
 	{
 	    int FoundMLEs = 0;
 
-            { /* Need to initialize volume replica transient members first. */
+	    { /* Need to initialize volume replica transient members first. */
                 volrep_iterator next;
                 volrep *v;
-                while ((v = next()))
+                while ((v = next())) {
                     v->ResetTransient();
+		    /* grab extra reference until all fsos are initialized */
+		    v->hold();
+		}
             }
             eprint("\t%d volume replicas", VDB->volrep_hash.count());
             {
@@ -211,6 +214,8 @@ void VolInit()
                 while ((v = next())) {
                     /* Initialize transient members. */
                     v->ResetTransient();
+		    /* grab extra reference until all fsos are initialized */
+		    v->hold();
                     FoundMLEs += v->CML.count();
                 }
             }
@@ -263,6 +268,15 @@ void VolInit()
     VOLD_Init();
 }
 
+void VolInitPost(void)
+{
+    /* fsos are initialized, drop the extra references. */
+    repvol_iterator rnext;
+    volrep_iterator vnext;
+    volent *v;
+    while ((v = rnext()) || (v = vnext()))
+	v->release();
+}
 
 int VOL_HashFN(const void *key)
 {
@@ -270,18 +284,20 @@ int VOL_HashFN(const void *key)
     return volid->Realm + volid->Volume;
 }
 
-static void GetRootVolume(Realm *realm, char **buf)
+static int GetRootVolume(Realm *realm, char **buf)
 {
     connent *c = NULL;
     RPC2_BoundedBS RVN;
     char *rvn = NULL;
-    int code;
+    int code, ret = 0;
+
 
     /* Get the connection. */
     if (realm->GetAdmConn(&c) != 0) {
 	LOG(100, ("GetRootVolume: can't get admin connection for realm %s!\n",
 		  realm->Name()));
 	RPCOpStats.RPCOps[ViceGetRootVolume_OP].bad++;
+	ret = -1;
 	goto err_exit;
     }
 
@@ -316,7 +332,7 @@ err_exit:
 	free(rvn);
 
     *buf = strdup(realm->GetRootVolName());
-    return;
+    return ret;
 }
 
 /* Allocate database from recoverable store. */
@@ -367,7 +383,6 @@ volent *vdb::Find(Volid *volid)
 	    return(v);
 	}
     }
-
     return(0);
 }
 
@@ -439,7 +454,8 @@ volent *vdb::Create(Realm *realm, VolumeInfo *volinfo, const char *volname)
     volid.Volume = volinfo->Vid;
 
     /* Check whether the key is already in the database. */
-    if ((v = Find(&volid))) {
+    v = Find(&volid);
+    if (v) {
 	if (strcmp(v->name, volname) != 0) {
 	    eprint("reinstalling volume %s (%s)", v->GetName(), volname);
 
@@ -462,7 +478,6 @@ volent *vdb::Create(Realm *realm, VolumeInfo *volinfo, const char *volname)
 	    err = GetVolReps(realm->Id(), volinfo, volreps);
 	    if (!err) {
 		Recov_BeginTrans();
-
 		for (i = 0; i < VSG_MEMBERS; i++) {
 		    /* did the volume replica change? */
 		    if (vp->volreps[i] != volreps[i]) {
@@ -524,9 +539,9 @@ volent *vdb::Create(Realm *realm, VolumeInfo *volinfo, const char *volname)
         }
     }
 
-    if (v) v->hold();
-    else LOG(0, ("vdb::Create: (%x.%x, %s, %d) failed\n", realm->Id(),
-		 volinfo->Vid, volname, 0/*AllocPriority*/));
+    if (!v)
+	LOG(0, ("vdb::Create: (%x.%x, %s, %d) failed\n", realm->Id(),
+		volinfo->Vid, volname, 0/*AllocPriority*/));
     return(v);
 }
 
@@ -594,7 +609,10 @@ int vdb::Get(volent **vpp, Realm *prealm, const char *name, fsobj *f)
      * root volume, try to get it from the servers */
     if (volname[0] == '\0' && realm != prealm) {
 	free(volname);
-	GetRootVolume(realm, &volname);
+	if (GetRootVolume(realm, &volname)) {
+	    code = ENOTCONN;
+	    goto error_exit;
+	}
     }
 
     /* Ivan Popov's suggestion, we just need to allow for long volume
@@ -602,7 +620,10 @@ int vdb::Get(volent **vpp, Realm *prealm, const char *name, fsobj *f)
     if (volname[0] == '\0') {
 	free(volname);
 	volname = (char *)malloc(MAXPATHLEN);
-	if (!volname) goto error_exit;
+	if (!volname) {
+	    code = ENOMEM;
+	    goto error_exit;
+	}
 	f->GetPath(volname, PATH_REALM);
     }
 
@@ -644,10 +665,8 @@ int vdb::Get(volent **vpp, Realm *prealm, const char *name, fsobj *f)
 
 	goto error_exit;
     }
-    if (v) {
-	if (v->GetVolumeId() == volinfo.Vid)
-	    goto Exit;
-
+    if (v && v->GetVolumeId() != volinfo.Vid)
+    {
 	eprint("Mapping changed for volume %s@%s (%x --> %x)",
 	       volname, realm->Name(), v->GetVolumeId(), volinfo.Vid);
 
@@ -673,7 +692,9 @@ int vdb::Get(volent **vpp, Realm *prealm, const char *name, fsobj *f)
 	v->release();
     }
 
-    /* Attempt the create. */
+    /* Attempt the create will be mostly a noop if the volume already existed,
+     * but it will grow or shrink the volume correctly if the volume
+     * replication group has changed. */
     v = Create(realm, &volinfo, volname);
 
     if (!v) {
@@ -791,7 +812,7 @@ int vdb::WriteDisconnect(unsigned age, unsigned time)
     int code = 0;
 
     while ((v = next())) {
-        code = v->WriteDisconnect(age, time); 
+        code = v->WriteDisconnect(age, time);
         if (code) break;
     }
     return(code);
@@ -919,7 +940,7 @@ void volent::ResetVolTransients()
      * sync doesn't need to be initialized. 
      * It's used only for LWP_Wait and LWP_Signal. 
      */
-    refcnt = 0;
+    refcnt = 1;
 }
 
 
@@ -957,8 +978,6 @@ void volent::hold(void)
 
 void volent::release(void)
 {
-    int intrans;
-
     refcnt--;
 
     CODA_ASSERT(refcnt >= 0);
@@ -970,17 +989,14 @@ void volent::release(void)
     if (IsReplicated() && ((repvol *)this)->CML.count() != 0)
 	return;
 
-    /* we could be called when there already is a transaction ongoing or we
-     * might have to start our own transaction... */
-    intrans = rvmlib_in_transaction();
-    if (!intrans)
-	Recov_BeginTrans();
+    /* we could be called when there already is a transaction ongoing, we
+     * could start our own transaction, or just leave it up to getdown... */
+    int intrans = rvmlib_in_transaction();
 
+    if (!intrans) Recov_BeginTrans();
     if (IsReplicated()) delete (repvol *)this;
-    else	        delete (volrep *)this;
-
-    if (!intrans)
-	Recov_EndTrans(MAXFP);
+    else		delete (volrep *)this;
+    if (!intrans) Recov_EndTrans(MAXFP);
 }
 
 int volent::IsReadWriteReplica()
@@ -1014,7 +1030,7 @@ int volent::IsReadWriteReplica()
 */
 
 #define	VOLBUSY(vol)\
-    ((vol)->resolver_count > 0 || (vol)->mutator_count > 0 || (vol)->observer_count > 0)
+    ((vol)->resolver_count || (vol)->mutator_count || (vol)->observer_count)
 /* MUST NOT be called from within transaction! */
 int volent::Enter(int mode, uid_t uid)
 {
@@ -1183,14 +1199,11 @@ int volent::Enter(int mode, uid_t uid)
 	case VM_RESOLVING:
 	    {
 	    CODA_ASSERT(IsReplicated());
-	    if (state != Resolving || resolver_count != 0 || 
-		mutator_count != 0 || observer_count != 0 ||
-		flags.transition_pending)
-		{ print(logFile); CHOKE("volent::Enter: resolving"); }
-
 	    /* acquire exclusive volume-pgid-lock for RESOLVING */
 	    int proc_key = vp->u.u_pgid;
-	    while (shrd_count > 0 || (excl_count > 0 && proc_key != excl_pgid)) {
+	    while (VOLBUSY(this) || flags.transition_pending ||
+		   shrd_count > 0 || (excl_count > 0 && proc_key != excl_pgid))
+	    {
 		/* 
 		 * must wait until all the volume-pgid-locks are released.
 		 * no need to check for VM_NDELAY and excl_pgid here.
@@ -1280,7 +1293,7 @@ void volent::Exit(int mode, uid_t uid)
 	case VM_RESOLVING:
 	    {
 	    CODA_ASSERT(IsReplicated());
-	    if (state != Resolving || resolver_count != 1 || !flags.transition_pending)
+	    if (state != Resolving || resolver_count == 0 || !flags.transition_pending)
 		{ print(logFile); CHOKE("volent::Exit: resolving"); }
 
 	    resolver_count--;
@@ -1338,7 +1351,7 @@ void volent::TakeTransition()
         if (rv->ResListCount())
             nextstate = Resolving;
 
-        else if (flags.logv || flags.sync_reintegrate || rv->GetCML()->count())
+        else if (flags.logv || rv->GetCML()->count())
             nextstate = Logging;
     }
 
@@ -1587,21 +1600,21 @@ int repvol::SyncCache(VenusFid * fid)
 {
     LOG(1,("volent::SyncCache()\n"));
 
-    //	    if (flags.transition_pending && VOLBUSY(this)) { 
-    // wait until they get out of our volume
-
     flags.transition_pending = 1;
-    flags.sync_reintegrate = 1;
-
-    while (flags.transition_pending) { 
-	while (VOLBUSY(this))
-	    VprocWait((char*)&shrd_count);
-
-        TakeTransition();
+    while (VOLBUSY(this)) {
+	VprocWait((char*)&shrd_count);
+	flags.transition_pending = 1;
     }
 
-    //Reintegrate();
-    flags.sync_reintegrate = 0;
+    flags.sync_reintegrate = 1;
+
+    while (flags.transition_pending && !VOLBUSY(this))
+	TakeTransition();
+
+    /* the sync_reintegrate flag is cleared in repvol::Reintegrate to avoid
+     * recursion when exiting the volume in cases where the reintegration
+     * required resolution or repair */
+    // flags.sync_reintegrate = 0;
 
     return 0;
 }
@@ -2766,27 +2779,62 @@ void volent::ListCache(FILE* fp, int long_format, unsigned int valid)
 }
 
 
-/*  *****  Volume Iterator  *****  */
+/*  *****  Volume Iterators  *****  */
 
-repvol_iterator::repvol_iterator(Volid *key) : rec_ohashtab_iterator(VDB->repvol_hash, (void *)key) { }
+volent_iterator::volent_iterator(rec_ohashtab &hashtab, Volid *key) :
+    rec_ohashtab_iterator(hashtab, (void *)key) { }
 
-volrep_iterator::volrep_iterator(Volid *key) : rec_ohashtab_iterator(VDB->volrep_hash, (void *)key) { }
+repvol_iterator::repvol_iterator(Volid *key) :
+    volent_iterator(VDB->repvol_hash, key) { }
+
+volrep_iterator::volrep_iterator(Volid *key) :
+    volent_iterator(VDB->volrep_hash, key) { }
+
+volent_iterator::~volent_iterator()
+{
+    rec_olink *c = NULL;
+    if (nextlink)
+	c = nextlink->clink;
+    if (c && c != (void *)-1) {
+	volent *prev = strbase(volent, c, handle);
+	prev->release();
+    }
+}
+
+volent *volent_iterator::operator()()
+{
+    rec_olink *o, *c = NULL;
+    volent *next = NULL;
+
+    if (nextlink)
+	c = nextlink->clink;
+
+    o = rec_ohashtab_iterator::operator()();
+    if (o) {
+	next = strbase(volent, o, handle);
+	next->hold();
+    }
+
+    if (c && c != (void *)-1) {
+	volent *prev = strbase(volent, c, handle);
+	prev->release();
+    }
+    return next;
+}
 
 repvol *repvol_iterator::operator()()
 {
-    rec_olink *o = rec_ohashtab_iterator::operator()();
-    if (!o) return(0);
-
-    repvol *v = strbase(repvol, o, handle);
-    return(v);
+    volent *v = volent_iterator::operator()();
+    if (!v) return(0);
+    assert(v->IsReplicated());
+    return (repvol *)v;
 }
 
 volrep *volrep_iterator::operator()()
 {
-    rec_olink *o = rec_ohashtab_iterator::operator()();
-    if (!o) return(0);
-
-    volrep *v = strbase(volrep, o, handle);
-    return(v);
+    volent *v = volent_iterator::operator()();
+    if (!v) return(0);
+    assert(!v->IsReplicated());
+    return (volrep *)v;
 }
 
