@@ -113,7 +113,9 @@ vproc *FindVproc(int vpid) {
 /* It's job is to initialize state which needs to be set in the context of the
  * new vproc. Certain things can't be done in the vproc::ctor because that may
  * be executed in a different context! */
-void VprocPreamble(struct Lock *init_lock) {
+void VprocPreamble(void *arg)
+{
+    struct Lock *init_lock = (struct Lock *)arg;
 
     /* This lock is released by start_thread, as soon as the initialization has
      * finalized (aka. this->lwpid has been set */
@@ -396,8 +398,8 @@ void vproc::start_thread(void)
 	/* Create an LWP for this vproc. */
 	/* pass the lock, instead of the function; we can get back to the
 	 * function once we know which vproc the new lwp is */
-	int lwprc = LWP_CreateProcess((PFIC)VprocPreamble, stacksize, lwpri,
-				      (char *)&init_lock, name, (PROCESS *)&lwpid);
+	int lwprc = LWP_CreateProcess(VprocPreamble, stacksize, lwpri,
+				      &init_lock, name, (PROCESS *)&lwpid);
 	if (lwprc != LWP_SUCCESS)
 	    CHOKE("vproc::start_thread: LWP_CreateProcess(%d, %s) failed (%d)",
 		  stacksize, name, lwprc);
@@ -417,14 +419,13 @@ void vproc::start_thread(void)
 	    CHOKE("VprocInit: IOMGR_Initialize failed (%d)", iomgrrc);
 
 	initialized = 1;
-	VprocPreamble(&init_lock);
+	VprocPreamble((void *)&init_lock);
     }
 }
 
 void vproc::main(void)
 {
-    CODA_ASSERT(func != NULL);
-    
+    CODA_ASSERT(func);
     func();
 }
 
@@ -485,7 +486,7 @@ void vproc::GetStamp(char *buf) {
     time_t curr_time = Vtime();
     struct tm *lt = localtime(&curr_time);
     sprintf(buf, "[ %c(%02d) : %04d : %02d:%02d:%02d ] ",
-	     t, vpid, seq, lt->tm_hour, lt->tm_min, lt->tm_sec);
+	    t, vpid, seq, lt->tm_hour, lt->tm_min, lt->tm_sec);
 }
 
 
@@ -796,14 +797,13 @@ void va_init(struct coda_vattr *vap) {
     vap->va_uid = VA_IGNORE_UID;
     vap->va_gid = VA_IGNORE_GID;
     vap->va_fileid = VA_IGNORE_ID;
-    vap->va_atime.tv_sec = VA_IGNORE_TIME1;
-    vap->va_atime.tv_nsec = VA_IGNORE_TIME2;
+    vap->va_mtime.tv_sec = VA_IGNORE_TIME1;
+    vap->va_mtime.tv_nsec = 0;
     vap->va_bytes = VA_IGNORE_STORAGE;
     vap->va_nlink = VA_IGNORE_NLINK;
     vap->va_size = VA_IGNORE_SIZE;
     vap->va_blocksize = VA_IGNORE_BLOCKSIZE;
-    vap->va_mtime = vap->va_atime;
-    vap->va_ctime = vap->va_atime;
+    vap->va_atime = vap->va_ctime = vap->va_mtime;
     vap->va_rdev = (long long unsigned int)VA_IGNORE_RDEV;
     vap->va_flags = 0; /* must be 0, not IGNORE_FLAGS for BSD */
 }
