@@ -169,7 +169,7 @@ class vproc : public olink {
   friend void Rtry_Wait();
   friend void Rtry_Signal();
   friend vproc *FindVproc(int);
-  friend void VprocPreamble(struct Lock *);
+  friend void VprocPreamble(void *);
   friend vproc *VprocSelf();
   friend int VprocIdle();
   friend int VprocInterrupted();
@@ -352,9 +352,8 @@ struct venus_cnode {
 #define VA_IGNORE_RDEV		((cdev_t)-1)
 #define VA_IGNORE_STORAGE	((u_quad_t) -1)
 #define VA_IGNORE_MODE		((u_short)-1)
-#define VA_IGNORE_UID		((cuid_t) -1)
-#define VA_IGNORE_TIME2		((long) -1)
-#define VA_IGNORE_GID		((cgid_t) -1)
+#define VA_IGNORE_UID		((uid_t) -1)
+#define VA_IGNORE_GID		((gid_t) -1)
 #define VA_IGNORE_SIZE		((u_quad_t)-1) 
 #define VA_IGNORE_TIME1		((time_t)-1)
 #define VA_IGNORE_FLAGS		((u_long)-1)
