@@ -193,6 +193,8 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			    worker *w = (worker *)this;
 			    union outputArgs *out;
 			    out = (union outputArgs *)w->msg->msg_buf;
+			    out->coda_ioctl.data =
+				(char *)sizeof(struct coda_ioctl_out);
 			    out->coda_ioctl.len = 0;
 			    out->coda_ioctl.oh.result = 0;
 			    w->Return(w->msg, sizeof (struct coda_ioctl_out));
@@ -233,7 +235,8 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			if (!f->IsDir()) { u.u_error = ENOTDIR; break; }
 
 			/* Verify that the target doesn't exist. */
-			u.u_error = f->Lookup(&target_fso, 0, link_name, u.u_uid, CLU_CASE_SENSITIVE);
+			u.u_error = f->Lookup(&target_fso, NULL, link_name,
+					      u.u_uid, CLU_CASE_SENSITIVE);
 			FSDB->Put(&target_fso);
 			if (u.u_error == 0) { u.u_error = EEXIST; break; }
 			if (u.u_error != ENOENT) { break; }
@@ -295,7 +298,8 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			    { u.u_error = ENOTDIR; break; }
 
 			/* Get the target object. */
-			u.u_error = f->Lookup(&target_fso, 0, target_name, u.u_uid, CLU_CASE_SENSITIVE);
+			u.u_error = f->Lookup(&target_fso, NULL, target_name,
+					      u.u_uid, CLU_CASE_SENSITIVE);
 			if (u.u_error) break;
 
 			/* Verify that target is a mount point (either valid or dangling). */
@@ -348,7 +352,8 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
                         }
 
 			/* Get the target object. */
-			u.u_error = f->Lookup(&target_fso, 0, target_name, u.u_uid, CLU_CASE_SENSITIVE);
+			u.u_error = f->Lookup(&target_fso, NULL, target_name,
+					      u.u_uid, CLU_CASE_SENSITIVE);
 			if (u.u_error) {
 			    FSDB->Put(&target_fso);
 			    break;
@@ -381,17 +386,26 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			}
 
 		    case _VIOC_GETPFID:
-			{
-			if (data->in_size != (int)sizeof(VenusFid))
+		    {
+			if (data->in_size <= sizeof(VenusFid) || 
+			    *((char *)data->in + data->in_size - 1) != '\0')
 			    { u.u_error = EINVAL; break; }
-			VenusFid *fid = (VenusFid *)data->in;
+
+			ViceFid fid;
+			memcpy(&fid, data->in, sizeof(ViceFid));
+			char *realmname = (char *)data->in + sizeof(ViceFid);
+			Realm *realm = REALMDB->GetRealm(realmname);
+
+			VenusFid vfid;
+			MakeVenusFid(&vfid, realm->Id(), &fid);
 
 			FSDB->Put(&f);
-			u.u_error = FSDB->Get(&f, fid, u.u_uid, RC_STATUS);
+
+			u.u_error = FSDB->Get(&f, &vfid, u.u_uid, RC_STATUS);
 			if (u.u_error) break;
 
 			/* if we're at a mount point, back up over it. */
-			if (f->IsRoot() && !f->IsVenusRoot()) {
+			if (f->IsRoot()) {
 			    if (f->u.mtpoint == 0) 
 				{ u.u_error = ENOENT; break; }
 
@@ -402,8 +416,8 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 		        }
 
 			/* Copy out the parent fid. */
-			memcpy(data->out, &f->pfid, sizeof(VenusFid));
-			data->out_size = (short)sizeof(VenusFid);
+			memcpy(data->out, MakeViceFid(&f->pfid), sizeof(ViceFid));
+			data->out_size = (short)sizeof(ViceFid);
 
 			break;
 			}
@@ -492,8 +506,7 @@ O_FreeLocks:
 		    }
 		    /* Backup and use volroot's mount point if directed. */
 		    if (data->in_size == sizeof(int) && *(int *)data->in != 0) {
-			if (FID_EQ(&f->fid, &rootfid) ||
-			    !FID_IsVolRoot(&f->fid) || f->u.mtpoint == 0) {
+			if (!FID_IsVolRoot(&f->fid) || f->u.mtpoint == 0) {
 			    u.u_error = EINVAL;
 			    break;
 			}
@@ -549,10 +562,6 @@ OI_FreeLocks:
 	case _VIOC_ENABLEASR:
 	case _VIOC_DISABLEASR: 
 	case _VIOC_LISTCACHE_VOLUME:
-	case _VIOC_BEGINWB:
-	case _VIOC_STATUSWB:
-	case _VIOC_ENDWB:
-	case _VIOC_AUTOWB:
 	case _VIOC_SYNCCACHE:
 	case _VIOC_REDIR:
 	    {
