@@ -331,8 +331,8 @@ FreeLocks:
 	va_init(vap);
 	vap->va_mode = 0444;
 	vap->va_type = FTTOVT(SymbolicLink);
-	vap->va_uid = (short)V_UID;
-	vap->va_gid = (short)V_GID;
+	vap->va_uid = V_UID;
+	vap->va_gid = V_GID;
 	vap->va_nlink = 1;
 
 	/* @XXXXXXXX.YYYYYYYY.ZZZZZZZZ. */
@@ -369,35 +369,39 @@ void vproc::setattr(struct venus_cnode *cp, struct coda_vattr *vap) {
      * allow calls that clear the field.  
      */
     /* Cannot set these attributes. */
-    if ( (vap->va_fileid != VA_IGNORE_ID) ||
-	 (vap->va_nlink != VA_IGNORE_NLINK) ||
-	 (vap->va_blocksize != VA_IGNORE_BLOCKSIZE) ||
-	 (vap->va_rdev != VA_IGNORE_RDEV) ||
-	 (vap->va_flags != VA_IGNORE_FLAGS && vap->va_flags != 0) ||
-	  (vap->va_bytes != VA_IGNORE_STORAGE) ) {
+    if (vap->va_fileid != VA_IGNORE_ID ||
+	vap->va_nlink != VA_IGNORE_NLINK ||
+	vap->va_blocksize != VA_IGNORE_BLOCKSIZE ||
+	vap->va_rdev != VA_IGNORE_RDEV ||
+	(vap->va_flags != VA_IGNORE_FLAGS && vap->va_flags != 0) ||
+	vap->va_bytes != VA_IGNORE_STORAGE)
+    {
 	    u.u_error = EINVAL; 
 	    return; 
     }
 
     /* Should be setting at least one of these. */
-    if ( (vap->va_mode == VA_IGNORE_MODE) &&
-	 (vap->va_uid == VA_IGNORE_UID) &&
-	 (vap->va_gid == VA_IGNORE_GID) &&
-	 (vap->va_size == VA_IGNORE_SIZE) &&
-	 (vap->va_flags == VA_IGNORE_FLAGS) &&
-	 (vap->va_atime.tv_sec == VA_IGNORE_TIME1) &&
-	 (vap->va_mtime.tv_sec == VA_IGNORE_TIME1) &&
-	 (vap->va_ctime.tv_sec == VA_IGNORE_TIME1) )
-
-	CHOKE("vproc::setattr: no attributes specified");
+    if (vap->va_mode == VA_IGNORE_MODE &&
+	vap->va_uid == VA_IGNORE_UID &&
+	vap->va_size == VA_IGNORE_SIZE &&
+	// We don't actually do anything with these attributes, just ignore...
+	//vap->va_gid == VA_IGNORE_GID &&
+	//vap->va_flags == VA_IGNORE_FLAGS &&
+	//vap->va_atime.tv_sec == VA_IGNORE_TIME1 &&
+	//vap->va_ctime.tv_sec == VA_IGNORE_TIME1 &&
+	vap->va_mtime.tv_sec == VA_IGNORE_TIME1)
+    {
+	u.u_error = 0;
+	return;
+    }
 
     for (;;) {
 	Begin_VFS(&cp->c_fid, CODA_SETATTR);
 	if (u.u_error) break;
 
-	/* If we are truncating a file to any non-zero size we NEED the data */
 	rcrights = RC_STATUS;
 
+	/* If we are truncating a file to any non-zero size we NEED the data */
 	/* va_size is unsigned long long, so we cannot use a > 0 test */
 	if (vap->va_size != 0 && vap->va_size != VA_IGNORE_SIZE)
 	    rcrights |= RC_DATA;
@@ -427,7 +431,7 @@ void vproc::setattr(struct venus_cnode *cp, struct coda_vattr *vap) {
             if (vap->va_mode != VA_IGNORE_MODE) {
                 /* setuid is not desirable on a distributed fs. Use a link to
                  * a local binary to preserve local policies */
-                if (S_ISREG(vap->va_mode) &&
+                if (f->IsFile() &&
                     vap->va_mode & (S_ISUID | S_ISGID))
                 {
                     u.u_error = EPERM;
@@ -445,10 +449,7 @@ void vproc::setattr(struct venus_cnode *cp, struct coda_vattr *vap) {
 		u.u_error = f->Access((long)PRSFS_ADMINISTER, 0, u.u_uid);
 		if (u.u_error) goto FreeLocks;
 	    }
-	    /* gid should be V_GID for chown requests, 
-	       VA_IGNORE_GID otherwise */
-	    if (vap->va_gid != VA_IGNORE_GID)
-	        vap->va_gid = V_GID;
+
 	    /* truncate, ftruncate */
 	    if (vap->va_size != VA_IGNORE_SIZE) {
 		if (!f->IsFile()) {
@@ -462,9 +463,7 @@ void vproc::setattr(struct venus_cnode *cp, struct coda_vattr *vap) {
 	    }
 
 	    /* utimes */
-	    if ( (vap->va_atime.tv_sec != VA_IGNORE_TIME1) ||
-		 (vap->va_mtime.tv_sec != VA_IGNORE_TIME1) ||
-		 (vap->va_ctime.tv_sec != VA_IGNORE_TIME1) ) {
+	    if (vap->va_mtime.tv_sec != VA_IGNORE_TIME1) {
 		    u.u_error = f->Access((long)PRSFS_WRITE, 0, u.u_uid);
 		    if (u.u_error) goto FreeLocks;
 	    }
@@ -576,8 +575,7 @@ void vproc::lookup(struct venus_cnode *dcp, char *name,
 	    parent_fso = 0;		    /* Fake a FSDB->Put(&parent_fso); */
 	}
 	else if (STREQ(name, "..")) {
-	    if (parent_fso->IsRoot() && parent_fso->u.mtpoint &&
-		!parent_fso->IsVenusRoot())
+	    if (parent_fso->IsRoot() && parent_fso->u.mtpoint)
 		u.u_error = FSDB->Get(&target_fso, &parent_fso->u.mtpoint->pfid, u.u_uid, RC_DATA);
 	    else {
 		target_fso = parent_fso->pfso;
@@ -592,7 +590,8 @@ void vproc::lookup(struct venus_cnode *dcp, char *name,
 	}
 	else {
 	    VenusFid inc_fid;
-	    u.u_error = parent_fso->Lookup(&target_fso, &inc_fid, name, u.u_uid, flags);
+	    u.u_error = parent_fso->Lookup(&target_fso, &inc_fid, name, u.u_uid,
+					   flags | CLU_TRAVERSE_MTPT);
 	    if (u.u_error) {
 		if (u.u_error == EINCONS) {
 		    u.u_error = 0;
@@ -651,6 +650,7 @@ void vproc::create(struct venus_cnode *dcp, char *name, struct coda_vattr *vap,
     if (u.u_error) return;
 
     for (;;) {
+	int flags = CLU_CASE_SENSITIVE;
 	Begin_VFS(&dcp->c_fid, CODA_CREATE);
 	if (u.u_error) break;
 
@@ -661,14 +661,13 @@ void vproc::create(struct venus_cnode *dcp, char *name, struct coda_vattr *vap,
 	    { u.u_error = ENOTDIR; goto FreeLocks; }
 
 	/* Get the target object (if it exists). */
-	if ((LRDB->repair_root_fid) && (parent_fso->IsLocalObj() || 
-					LRDB->RFM_IsRootParent(&parent_fso->fid))) {
+	if (LRDB->repair_root_fid &&
+	    (parent_fso->IsLocalObj() ||
+	     LRDB->RFM_IsRootParent(&parent_fso->fid)))
 	    /* cross mount-point when under local/global repair */
-	    VenusFid dummy;
-	    u.u_error = parent_fso->Lookup(&target_fso, &dummy, name, u.u_uid, CLU_CASE_SENSITIVE);
-	} else {
-	    u.u_error = parent_fso->Lookup(&target_fso, 0, name, u.u_uid, CLU_CASE_SENSITIVE);
-	}
+	    flags |= CLU_TRAVERSE_MTPT;
+
+	u.u_error = parent_fso->Lookup(&target_fso, NULL, name, u.u_uid, flags);
 	if (u.u_error == 0) {
 	    FSDB->Put(&parent_fso);	    /* avoid deadlock! */
 
@@ -767,7 +766,8 @@ void vproc::remove(struct venus_cnode *dcp, char *name)
 	    { u.u_error = ENOTDIR; goto FreeLocks; }
 
 	/* Get the target object. */
-	u.u_error = parent_fso->Lookup(&target_fso, 0, name, u.u_uid, CLU_CASE_SENSITIVE);
+	u.u_error = parent_fso->Lookup(&target_fso, NULL, name, u.u_uid,
+				       CLU_CASE_SENSITIVE);
 	if (u.u_error) goto FreeLocks;
 
 	/* Verify that it is not a directory. */
@@ -850,19 +850,19 @@ void vproc::link(struct venus_cnode *scp, struct venus_cnode *dcp,
             if (u.u_error) goto FreeLocks;
         }
 
+	/* Verify that the target doesn't exist. */
+	u.u_error = parent_fso->Lookup(&target_fso, NULL, toname, u.u_uid,
+				       CLU_CASE_SENSITIVE);
+	if (u.u_error == 0) { u.u_error = EEXIST; goto FreeLocks; }
+	if (u.u_error != ENOENT) goto FreeLocks;
+	u.u_error = 0;
+
         /* Don't allow hardlinks across different directories */
         if (!parent_fso->dir_IsParent(&scp->c_fid)) {
             /* Source exists, but it is not in the target parent. */
             u.u_error = EXDEV;
             goto FreeLocks;
         }
-                                                             
-	/* Verify that the target doesn't exist. */
-	u.u_error = parent_fso->Lookup(&target_fso, 0, toname, u.u_uid,
-				       CLU_CASE_SENSITIVE);
-	if (u.u_error == 0) { u.u_error = EEXIST; goto FreeLocks; }
-	if (u.u_error != ENOENT) goto FreeLocks;
-	u.u_error = 0;
 
 	/* Verify that we have insert permission on the target parent. */
 	u.u_error = parent_fso->Access((long)PRSFS_INSERT, 0, u.u_uid);
@@ -968,10 +968,11 @@ void vproc::rename(struct venus_cnode *spcp, char *name,
 	{
 	    fsobj *f = (SameParent ? t_parent_fso : s_parent_fso);
 #ifdef DJGPP
-	    u.u_error = f->Lookup(&s_fso, 0, name, u.u_uid, CLU_CASE_INSENSITIVE);
+	    int flags = CLU_CASE_INSENSITIVE;
 #else
-	    u.u_error = f->Lookup(&s_fso, 0, name, u.u_uid, CLU_CASE_SENSITIVE);
+	    int flags = CLU_CASE_SENSITIVE;
 #endif
+	    u.u_error = f->Lookup(&s_fso, NULL, name, u.u_uid, flags);
 	    if (u.u_error) goto FreeLocks;
 
 	    if (s_fso->IsMtPt() || s_fso->IsMTLink())
@@ -985,7 +986,8 @@ void vproc::rename(struct venus_cnode *spcp, char *name,
 		if (u.u_error) goto FreeLocks;
 	    }
 	}
-	u.u_error = t_parent_fso->Lookup(&t_fso, 0, toname, u.u_uid, CLU_CASE_SENSITIVE);
+	u.u_error = t_parent_fso->Lookup(&t_fso, NULL, toname, u.u_uid,
+					 CLU_CASE_SENSITIVE);
 	if (u.u_error) {
 	    if (u.u_error != ENOENT) goto FreeLocks;
 	    u.u_error = 0;
@@ -1135,7 +1137,8 @@ void vproc::mkdir(struct venus_cnode *dcp, char *name,
 	if (!parent_fso->IsDir()) { u.u_error = ENOTDIR; goto FreeLocks; }
 
 	/* Verify that the target doesn't exist. */
-	u.u_error = parent_fso->Lookup(&target_fso, 0, name, u.u_uid, CLU_CASE_SENSITIVE);
+	u.u_error = parent_fso->Lookup(&target_fso, NULL, name, u.u_uid,
+				       CLU_CASE_SENSITIVE);
 	if (u.u_error == 0) { u.u_error = EEXIST; goto FreeLocks; }
 	if (u.u_error != ENOENT) goto FreeLocks;
 	u.u_error = 0;
@@ -1193,7 +1196,8 @@ void vproc::rmdir(struct venus_cnode *dcp, char *name)
 	if (!parent_fso->IsDir()) { u.u_error = ENOTDIR; goto FreeLocks; }
 
 	/* Get the target object. */
-	u.u_error = parent_fso->Lookup(&target_fso, 0, name, u.u_uid, CLU_CASE_SENSITIVE);
+	u.u_error = parent_fso->Lookup(&target_fso, NULL, name, u.u_uid,
+				       CLU_CASE_SENSITIVE);
 	if (u.u_error) goto FreeLocks;
 
 	/* Sanity check. */
@@ -1264,7 +1268,8 @@ void vproc::symlink(struct venus_cnode *dcp, char *contents,
 	if (!parent_fso->IsDir()) { u.u_error = ENOTDIR; goto FreeLocks; }
 
 	/* Verify that the target doesn't exist. */
-	u.u_error = parent_fso->Lookup(&target_fso, 0, name, u.u_uid, CLU_CASE_SENSITIVE);
+	u.u_error = parent_fso->Lookup(&target_fso, NULL, name, u.u_uid,
+				       CLU_CASE_SENSITIVE);
 	if (u.u_error == 0) { u.u_error = EEXIST; goto FreeLocks; }
 	if (u.u_error != ENOENT) goto FreeLocks;
 	u.u_error = 0;
