@@ -83,6 +83,11 @@ extern "C" {
 }
 #endif
 
+/* Darwin uses the same venus-kernel interface as BSD */
+#if defined(__APPLE__) && defined(__MACH__)
+#define __BSD44__
+#endif
+
 /* interfaces */
 /* from vicedep */
 #include <venusioctl.h>
@@ -372,9 +377,11 @@ void VFSMount()
 	mountdata.version = CODA_MOUNT_VERSION;
 	mountdata.fd = worker::muxfd;
 
-	error = mount("coda", venusRoot, "coda",  MS_MGC_VAL,
+	error = mount("coda", venusRoot, "coda",
+		      MS_MGC_VAL | MS_NOATIME | MS_NODEV | MS_NOSUID,
 		      islinux20 ? (void *)&kernDevice : (void *)&mountdata);
 
+
 	if (!error) {
 	    FILE *fd = setmntent("/etc/mtab", "a");
 	    struct mntent ent;
@@ -382,7 +389,7 @@ void VFSMount()
 		ent.mnt_fsname = "coda";
 		ent.mnt_dir    = venusRoot;
 		ent.mnt_type   = "coda";
-		ent.mnt_opts   = "rw";
+		ent.mnt_opts   = "rw,noatime,nosuid,nodev";
 		ent.mnt_freq   = 0;
 		ent.mnt_passno = 0;
 		addmntent(fd, &ent);
@@ -1230,6 +1237,8 @@ void worker::main(void)
 
 		if (type != 'V') {
 		    u.u_error = EOPNOTSUPP;
+		    out->coda_ioctl.data =
+			(char *)sizeof(struct coda_ioctl_out); 
                     out->coda_ioctl.len = 0;		
 		    size = sizeof(struct coda_ioctl_out);
 		    break;
@@ -1237,10 +1246,12 @@ void worker::main(void)
 
 		if (nr == _VIOC_UNLOADKERNEL) {
                     out->oh.result = 0;
+		    out->coda_ioctl.data =
+			(char *)sizeof(struct coda_ioctl_out); 
                     out->coda_ioctl.len = 0;		
                     /* we have to Resign here because we will exit before
                      * leaving the switch */
-                    Resign(msg, (int)sizeof(struct coda_ioctl_out) + data.out_size);
+                    Resign(msg, sizeof(struct coda_ioctl_out));
 
                     LOG(0, ("TERM: Venus exiting\n"));
                     RecovFlush(1);
@@ -1343,14 +1354,15 @@ void worker::main(void)
 		MAKE_CNODE(vtarget, in->coda_open_by_fd.Fid, 0);
 		open(&vtarget, in->coda_open_by_fd.flags);
 		
-                openfd = -1;
 		if (u.u_error == 0) {
-		    MarinerReport(&vtarget.c_fid, u.u_uid);
+		    int flags = (in->coda_open_by_fd.flags & C_O_WRITE) ?
+			O_RDWR : O_RDONLY;
+		    flags |= O_BINARY;
 
-		    openfd = ::open(vtarget.c_cfname, O_RDWR|O_BINARY, V_MODE);
+		    MarinerReport(&vtarget.c_fid, u.u_uid);
+		    openfd = ::open(vtarget.c_cfname, flags, V_MODE);
 		    out->coda_open_by_fd.fd = openfd;
-                    LOG(10, ("CODA_OPEN_BY_FD: fd = %d\n",
-                             out->coda_open_by_fd.fd));
+                    LOG(10, ("CODA_OPEN_BY_FD: fd = %d\n", openfd));
 		    size = sizeof (struct coda_open_by_fd_out);
 		}
 		break;
